@@ -1,11 +1,10 @@
 """
 main entry point to the program
 """
-import logging
-
 import pylogconf.core
 from pytconf import register_main, config_arg_parse_and_launch
 
+from pyflexebs import LOG_LEVEL
 from pyflexebs.endpoints.group_default import register_group_default
 
 
@@ -21,7 +20,7 @@ def main():
     """
     pyflexebs will enlarge/reduce your ebs volumes in real time
     """
-    pylogconf.core.setup(level=logging.INFO)
+    pylogconf.core.setup(level=LOG_LEVEL)
     register_all_groups()
     config_arg_parse_and_launch()
 
